"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Support_1 = require("./Support");
var ErrorMessage;
(function (ErrorMessage) {
    ErrorMessage["ArrayIsInvalidJSONSchema"] = "An array is not a valid JSON Schema";
    ErrorMessage["NullIsInvalidJSONSchema"] = "null is not a valid JSON Schema";
    ErrorMessage["RefMustBeString"] = "$ref must be a string";
    ErrorMessage["AdditionalTypesForbidRequired"] = "Can't have non-specified required properties but forbidden additionalTypes";
    ErrorMessage["NoTypeSpecified"] = "JSON Schema must specify at least one type";
    ErrorMessage["FalseSchemaNotSupported"] = "Schema \"false\" is not supported";
    ErrorMessage["RefWithFragmentNotAllowed"] = "Ref URI with fragment is not allowed: ${ref}";
    ErrorMessage["InvalidJSONSchemaType"] = "Value of type ${type} is not valid JSON Schemas";
    ErrorMessage["RequiredMustBeStringOrStringArray"] = "`required` must be string or array of strings, but is ${actual}";
    ErrorMessage["RequiredElementMustBeString"] = "`required` must contain only strings, but it has ${element}";
    ErrorMessage["TypeMustBeStringOrStringArray"] = "`type` must be string or array of strings, but is ${actual}";
    ErrorMessage["TypeElementMustBeString"] = "`type` must contain only strings, but it has ${element}";
    ErrorMessage["ArrayItemsMustBeStringOrArray"] = "Array items must be an array or an object, but is ${actual}";
    ErrorMessage["IDMustHaveAddress"] = "$id doesn't have an address: ${id}";
    ErrorMessage["WrongAccessorEntryArrayLength"] = "Accessor entry array must have the same number of entries as the ${operation}";
    ErrorMessage["SetOperationCasesIsNotArray"] = "${operation} cases must be an array, but is ${cases}";
})(ErrorMessage = exports.ErrorMessage || (exports.ErrorMessage = {}));
function messageError(message, props) {
    var userMessage = message;
    if (props !== undefined) {
        for (var _i = 0, _a = Object.getOwnPropertyNames(props); _i < _a.length; _i++) {
            var name = _a[_i];
            var value = props[name];
            if (typeof value !== "string") {
                value = JSON.stringify(value);
            }
            userMessage = userMessage.replace("${" + name + "}", value);
        }
    }
    return Support_1.panic(userMessage);
}
exports.messageError = messageError;
function messageAssert(assertion, message, props) {
    if (assertion)
        return;
    return messageError(message, props);
}
exports.messageAssert = messageAssert;
